@@ -29,7 +29,7 @@
 #include <gio/gio.h>
 #include <gconf/gconf-client.h>
 
-static const gchar convert_dir[] = "/usr/share/GConf/gsettings";
+static const gchar convert_dir[] = DATADIR "/GConf/gsettings";
 
 static gboolean verbose = FALSE;
 static gboolean dry_run = FALSE;
@@ -84,7 +84,11 @@ handle_file (const gchar *filename)
             g_print ("for storage at '%s'\n", schema_path[1]);
         }
 
-      settings = g_settings_new_with_path (schema_path[0], schema_path[1]);
+      if (schema_path[1] != NULL)
+        settings = g_settings_new_with_path (schema_path[0], schema_path[1]);
+      else
+        settings = g_settings_new (schema_path[0]);
+
       g_settings_delay (settings);
 
       error = NULL;
@@ -275,6 +279,10 @@ load_state (time_t  *mtime,
   filename = g_build_filename (g_get_user_data_dir (), "gsettings-data-convert", NULL);
   keyfile = g_key_file_new ();
 
+  /* ensure file exists */
+  if (!g_file_test (filename, G_FILE_TEST_EXISTS))
+    return;
+
   error = NULL;
   if (!g_key_file_load_from_file (keyfile, filename, 0, &error))
     {
